package httpserver

import (
	"fmt"
	"io"
	"net/http"
	"strings"
)

/*
	 Retrieve the site audit config file from Semrush
		returns a byte array of the body, the content type of the resp, and an error
*/
func (c *Controller) RetrieveStaticResource(path string) ([]byte, string, error) {
	url := fmt.Sprintf("https://static.semrush.com%s", path)
	req, err := http.NewRequest("GET", url, nil)
	if err != nil {
		return nil, "", err
	}
	req.AddCookie(c.Config.PhpSession)
	req.AddCookie(c.Config.SsoToken)
	req.Header.Set("User-Agent", c.Config.UserAgent)
	req.Header.Set("Referer", "https://www.semrush.com")
	req.Header.Set("Origin", "https://www.semrush.com")
	resp, err := c.Client.Do(req)
	if err != nil {
		return nil, "", err
	}
	defer resp.Body.Close()
	b, err := io.ReadAll(resp.Body)
	if err != nil {
		return nil, "", err
	}
	return b, resp.Header.Get("content-type"), nil

}

/*
Perform a call against the siteaudit api

	:param path: the URI path with the query
	:param query: the query to add to the request
	:returns a byte array of the response, the content type and an error
*/
func (c *Controller) SiteauditApiCall(method string, path string, query string, body io.Reader) ([]byte, string, error) {
	query = strings.ReplaceAll(query, "https://sem.bunnytools.shop", "https://www.semrush.com")
	url := fmt.Sprintf("https://www.semrush.com%s?%s", path, query)
	req, err := http.NewRequest(method, url, body)
	if err != nil {
		return nil, "", err
	}
	req.AddCookie(c.Config.PhpSession)
	req.AddCookie(c.Config.SsoToken)
	req.Header.Set("User-Agent", c.Config.UserAgent)
	req.Header.Set("Referer", "https://www.semrush.com")
	req.Header.Set("Origin", "https://www.semrush.com")
	resp, err := c.Client.Do(req)
	if err != nil {
		return nil, "", err
	}
	defer resp.Body.Close()
	b, err := io.ReadAll(resp.Body)
	if err != nil {
		return nil, "", err
	}
	return b, resp.Header.Get("content-type"), nil

}
